var CommodityDao = {
    /**
     * 查询
     * @param {Object} callBack(success,res|err)
     */
    loadCommodityInfo: function (keyword, commodityType, callBack) {

        var sql = "SELECT A.*,B.name AS typeName,C.name AS supplierName,CASE A.status when '0' then '下架' when '1' then '上架' when '2' then '卖完了' when '9' then '删除' else '' END AS statusName  " +
            " ,CASE A.labelPrint WHEN '0' THEN '否' WHEN '1' THEN  '是' ELSE '' END AS labelPrintName " +
            " ,CASE A.soldoutStatus WHEN '0' THEN '正常' WHEN '1' THEN '沽清' ELSE '' END AS soldoutStatusName " +
            " ,CASE A.selected WHEN '0' THEN '否' WHEN '1' THEN  '是' ELSE '' END AS selectedName " +
            " FROM commodityInfo A LEFT JOIN commodityType B ON A.typeId=B.id AND A.sellerId=B.sellerId " +
            " LEFT JOIN supplierInfo C ON A.supplierId=C.id AND A.sellerId=C.sellerId " +
            " WHERE 1=1 AND ifnull(A.status,'')<>'9' AND A.sellerId=? ";

        var keyArr = [];
        keyArr.push(loginInfo.storeId);
        if (!Ext.isEmpty(keyword)) {
            sql = sql + " AND  (A.name LIKE ? ESCAPE '^' OR A.pinyinCode ESCAPE '^' LIKE ? OR A.barcode LIKE ? ESCAPE '^')  ";
            keyArr.push('%' + replaceSQLiteCharacters(keyword) + '%');
            keyArr.push('%' + replaceSQLiteCharacters(keyword) + '%');
            keyArr.push('%' + replaceSQLiteCharacters(keyword) + '%');
        }
        if (!Ext.isEmpty(commodityType)) {
            sql = sql + ' and A.typeId=? ';
            keyArr.push(commodityType);
        }
        sql = sql + ' order by A.sequence asc ';

        loadBySqlParam(sql, keyArr, callBack);
    },

    loadStockInvRecordByPageTotal: function (paramArr, callback) {
        var sql = "SELECT count(id) as ttlNum FROM commodityStock where 1=1 AND sellerId=? ";
        var keyArr = [];
        keyArr.push(loginInfo.storeId);

        if (paramArr) {
            if (!Ext.isEmpty(paramArr[0])) {
                sql = sql + " AND changeType = ? ";//变更类型
                keyArr.push(paramArr[0]);
            }
            if (!Ext.isEmpty(paramArr[1])) {
                sql = sql + " AND commodityName LIKE ? ESCAPE '^' ";//商品名称
                keyArr.push('%' + replaceSQLiteCharacters(paramArr[1]) + '%')
            }
            if (paramArr[2]) {
                sql = sql + " AND date(changeDate) >=? ";//开始时间
                keyArr.push(paramArr[2]);
            }
            if (paramArr[3]) {
                sql = sql + " AND date(changeDate) <= ? ";//结束时间
                keyArr.push(paramArr[3]);
            }
        }
        getBySql(sql, keyArr, callback);

    },

    /**
     * 查询commodityStock数据
     * @param [Array] callBack(success,res|err)
     */
    loadCommocityStockData: function (paramArr, limitCount, pageIndex, callBack) {
        var sql = " SELECT commodityName, changeType , changeNum, commodityNum,changeDate,ifnull(changeNum,0)+ifnull(commodityNum,0) stock " +
            " FROM commodityStock where 1=1 AND sellerId=? ";
        var keyArr = [];
        keyArr.push(loginInfo.storeId);

        if (paramArr) {
            if (!Ext.isEmpty(paramArr[0])) {
                sql = sql + " AND changeType =? ";//变更类型
                keyArr.push(paramArr[0]);
            }
            if (!Ext.isEmpty(paramArr[1])) {
                sql = sql + " AND commodityName LIKE ? ESCAPE '^' ";//商品名称
                keyArr.push('%' + replaceSQLiteCharacters(paramArr[1]) + '%')
            }
            if (paramArr[2]) {
                sql = sql + " AND date(changeDate) >=? ";//开始时间
                keyArr.push(paramArr[2]);
            }
            if (paramArr[3]) {
                sql = sql + " AND date(changeDate) <= ? ";//结束时间
                keyArr.push(paramArr[3]);
            }
        }
        sql = sql + " ORDER BY changeDate DESC limit " + limitCount + " offset (" + pageIndex + "-1)*" + limitCount;
        loadBySqlParam(sql, keyArr, callBack);
    },


    /**
     * 查询库存预警
     * @param {Object} callBack(success,res|err)
     */
    loadCommodityStockWarnByPage: function (supplierId, commodityType, stockStatus, limitCount, pageIndex, callBack) {

        var sql = "SELECT A.*,B.name AS typeName,C.name AS supplierName, " +
            " CASE  when ifnull(A.stock,0)<ifnull(A.minStock,0) then '库存不足' when ifnull(A.stock,0)>ifnull(A.maxStock,0) then '库存过剩'  else '' END AS stockName  " +
            " FROM commodityInfo A LEFT JOIN commodityType B ON A.typeId=B.id AND A.sellerId=B.sellerId  " +
            " LEFT JOIN supplierInfo C ON A.supplierId=C.id " +
            " WHERE 1=1 AND A.status<>'9' AND A.minStock IS NOT NULL AND A.maxStock IS NOT NULL AND (ifnull(A.stock,0)< ifnull(A.minStock,0) or ifnull(A.stock,0)>ifnull(A.maxStock,0)) AND B.isInventory=1  ";

        var keyArr = [];
        sql = sql + ' AND A.sellerId=?  ';
        keyArr.push(loginInfo.storeId);


        if (!Ext.isEmpty(supplierId)) {
            sql = sql + ' AND A.supplierId=?  ';
            keyArr.push(supplierId);
        }
        if (!Ext.isEmpty(commodityType)) {
            sql = sql + ' and A.typeId=? ';
            keyArr.push(commodityType);
        }
        // console.log('status:'+stockStatus);
        //0,库存过剩 ,1 库存不足
        if (stockStatus == '0') {
            sql = sql + ' and ifnull(A.stock,0)>ifnull(A.maxStock,0) ';
        }
        else if (stockStatus == '1') {
            sql = sql + ' and ifnull(A.stock,0)<ifnull(A.minStock,0) ';
        }

        sql = sql + " Order by A.sequence asc limit " + limitCount + " offset (" + pageIndex + "-1)*" + limitCount;

        loadBySqlParam(sql, keyArr, callBack);
    },

    /**
     * 查询库存预警总数
     * @param {Object} callBack(success,res|err)
     */
    loadCommodityStockWarnByPageTotal: function (supplierId, commodityType, stockStatus, callBack) {

        var sql = "SELECT Count(A.id) as ttlNum " +
            " FROM commodityInfo A LEFT JOIN commodityType B ON A.typeId=B.id AND A.sellerId=B.sellerId   " +
            " LEFT JOIN supplierInfo C ON A.supplierId=C.id " +
            " WHERE 1=1 AND ifnull(A.status,'0')<>'9'  AND A.minStock IS NOT NULL AND A.maxStock IS NOT NULL AND (ifnull(A.stock,0)<ifnull(A.minStock,0) or ifnull(A.stock,0)>ifnull(A.maxStock,0)) AND B.isInventory=1  ";

        var keyArr = [];
        sql = sql + ' AND A.sellerId=?  ';
        keyArr.push(loginInfo.storeId);

        if (!Ext.isEmpty(supplierId)) {
            sql = sql + ' AND A.supplierId=?  ';
            keyArr.push(supplierId);
        }
        if (!Ext.isEmpty(commodityType)) {
            sql = sql + ' and A.typeId=? ';
            keyArr.push(commodityType);
        }
        // console.log('status:'+stockStatus);
        //0,库存过剩 ,1 库存不足
        if (stockStatus == '0') {
            sql = sql + ' and ifnull(A.stock,0)>ifnull(A.maxStock,0) ';
        }
        else if (stockStatus == '1') {
            sql = sql + ' and ifnull(A.stock,0)<ifnull(A.minStock,0) ';
        }


        getBySql(sql, keyArr, callBack);
    },


    /**
     * 根据条码查询数据
     * @param [Array] callBack(success,res|err)
     */
    loadSearchInfoByBarCode: function (barCode, callBack) {
        var sql = "SELECT a.id,a.name as commodityName,a.barcode,b.name AS typeName,ifnull(a.stock,0) as stock,ifnull(a.costPrice,0) as costPrice,c.name AS supplierName,a.supplierId,ifnull(b.isInventory,0) isInventory " +
            "FROM commodityInfo a " +
            "LEFT JOIN commodityType b ON a.typeId=b.id AND A.sellerId=B.sellerId " +
            "LEFT JOIN supplierInfo c ON a.supplierId=c.id  " +
            "WHERE ifnull(a.status,'0')<>'9' AND a.barCode=? AND A.sellerId=? ";
        loadBySqlParam(sql, [barCode, loginInfo.storeId], callBack);
    },

    /**
     *增加
     */
    add: function (sqlData, callBack) {
        insert("commodityInfo", sqlData, callBack);
    },

    /**
     *删除
     */
    delete: function (id, callBack) {
        del("commodityInfo", id, callBack);
    },

    /**
     * 更新
     * @param {Object} callback(success,err)
     */
    update: function (sqlData, id, callback) {
        update('commodityInfo', sqlData, id, callback)
    },

    /**
     * 查询数据
     * @param {Object} callback(success,err)
     */
    getById: function (id, callback) {
        var sql = "SELECT A.*,B.isInventory FROM commodityInfo A LEFT JOIN commodityType B ON A.typeId=B.id AND A.sellerId=B.sellerId " +
            " where ifnull(A.status,'0')<>'9' AND A.id=? AND A.sellerId=? order by A.sequence";
        getBySql(sql, [id, loginInfo.storeId], callback);
    },
    /**
    *根据单条id查询套餐商品
    *
    */
    getCombineCommodityById: function(id, callback){
        var sql = "SELECT * FROM commodityInfo WHERE ifnull(category, '')='2' AND id<>? AND sellerId=?";
        var keyArr = [];
        keyArr.push(id);
        keyArr.push(loginInfo.storeId);
        if(!Ext.isEmpty(id)){
            sql = sql + " AND comboMealsJson LIKE ?";
            keyArr.push("%"+replaceSQLiteCharacters(id)+"%");
        }
        loadBySqlParam(sql, keyArr, callback);
    },
    /*
    *根据一条或多条id查询是否包含在套餐商品
    *
    */
    getCombineCommodityByIds: function(ids, callback){
        //var sql = "SELECT count(*) AS result FROM commodityInfo WHERE ifnull(category,'')='2' AND sellerId=?";
        var sql = "SELECT count(*) AS result FROM commodityInfo WHERE ifnull(category,'')='2' AND ifnull(status, '0')<>'9' AND sellerId=?";
        var keyArr = [];
        var tempIds = [];
        keyArr.push(loginInfo.storeId);
        if(ids){
            if(ids.length > 0) {
                sql += " AND (";
            }
            for(var k = 0; k < ids.length; k++){
                var id = ids[k];
                sql += (k==0?"":" OR ") + "comboMealsJson like ?";
                keyArr.push("%" + id + "%");
                tempIds.push(id);
            }
            //sql += ") AND id not in (" + new Array(tempIds.length).fill("?").join(",") + ")";
            sql += ")";
            //keyArr = keyArr.concat(tempIds);
        }
        loadBySqlParam(sql, keyArr, callback)
    },
    /*
    * 根据一条或多条id查询时价菜商品总数
    * */
    getTimePriceCommodityByIds: function(ids, callback){
        var sql    = "SELECT count(*) AS result FROM commodityInfo WHERE ifnull(status, '0')<>'9' AND isTimePrice='1' AND sellerId=? ";
        var keyArr = [];
        var tempIds= [];
        keyArr.push(loginInfo.storeId);
        if(ids){
            if(ids.length > 0){
                sql += "AND id IN (";
            }
            for(var i = 0;i < ids.length; i++){
                tempIds.push(ids[i]);
            }
            sql += new Array(ids.length).fill('?').join(',') + ")";
            keyArr = keyArr.concat(tempIds);
            loadBySqlParam(sql, keyArr, callback);
        }
    },
    /**
     * 查询数据
     * @param {Object} callback(success,err)
     */
    getByBarcode: function (id, callback) {
        var sql = "SELECT * FROM commodityInfo where ifnull(status,'0')<>'9' AND barcode=? AND sellerId=? ";
        getBySql(sql, [id, loginInfo.storeId], callback);
    },

    /**
     * 根据条码查询有库存的商品
     * @param {Object} callback(success,err)
     */
    getByBarcodeIncludeInv: function (id, callback) {
        var sql = "SELECT A.*,ifnull(B.isInventory,0) isInventory FROM commodityInfo A LEFT JOIN commodityType B ON A.typeId=B.id AND A.sellerId=B.sellerId " +
            " where ifnull(A.status,'0')<>'9' AND  barcode=? and A.sellerId=? ";
        getBySql(sql, [id, loginInfo.storeId], callback);
    },

    /**
     * 分页查询
     * @param {Object} callBack(success,res|err)
     */
    loadCommodityInfoByPage: function (keyword, commodityType,categoryName,supportNormsName, includeInv, commodityCat, limitCount, pageIndex, callBack) {

        var sql = " SELECT A.*,B.name AS typeName,C.name AS supplierName,CASE A.status when '0' then '下架' when '1' then '上架' when '2' then '卖完了' when '9' then '删除' else '' END AS statusName  " +
            " ,CASE A.labelPrint WHEN '0' THEN '否' WHEN '1' THEN  '是' ELSE '' END AS labelPrintName " +
            " ,CASE A.soldoutStatus WHEN '0' THEN '正常' WHEN '1' THEN '沽清' ELSE '' END AS soldoutStatusName " +
            " ,CASE ifnull(A.selected,'0') WHEN '0' THEN '否' WHEN '1' THEN  '是' ELSE '' END AS selectedName " +
            " ,CASE ifnull(A.category,'1') WHEN '1' THEN '否' WHEN '2' THEN  '是' ELSE '' END AS categoryName " +
            " ,CASE ifnull(A.isSupportNorms,'0') WHEN '0' THEN '否' WHEN '1' THEN  '是' ELSE '否' END AS supportNormsName " +
            " FROM commodityInfo A LEFT JOIN commodityType B ON A.typeId=B.id AND A.sellerId=B.sellerId " +
            " LEFT JOIN supplierInfo C ON A.supplierId=C.id  WHERE 1=1 AND ifnull(B.status,'0') <> '9' AND ifnull(A.status,'0')<>'9'  and A.sellerId=? ";

        var keyArr = [];
        keyArr.push(loginInfo.storeId);
        if(!Ext.isEmpty(keyword)){
            sql = sql + " AND  (A.name LIKE ?  ESCAPE '^' OR A.pinyinCode LIKE ?  ESCAPE '^' OR A.barcode LIKE ?  ESCAPE '^' )  ";
            keyArr.push("%"+replaceSQLiteCharacters(keyword)+"%");
            keyArr.push("%"+replaceSQLiteCharacters(keyword)+"%");
            keyArr.push("%"+replaceSQLiteCharacters(keyword)+"%");
        }
        if (!Ext.isEmpty(commodityType)) {
            sql = sql + ' and A.typeId=? ';
            keyArr.push(commodityType);
        }
        if (!Ext.isEmpty(categoryName)) {
            sql = sql + ' and A.category=? ';
            keyArr.push(categoryName);
        }
        if (!Ext.isEmpty(supportNormsName)) {
            sql = sql + ' and A.isSupportNorms=? ';
            keyArr.push(supportNormsName);
        }
        if (!Ext.isEmpty(includeInv)) {
            sql = sql + ' and ifnull(B.isInventory,0)=? ';
            keyArr.push(includeInv);
        }
        if (!Ext.isEmpty(commodityCat)) {
            sql = sql + " and ifnull(A.category,'')=? ";
            keyArr.push(commodityCat);
        }

        sql = sql + " order by A.sequence,A.name,A.typeId asc limit " + limitCount + " offset (" + pageIndex + "-1)*" + limitCount;
        loadBySqlParam(sql, keyArr, callBack);
    },

    /**
     * 分页查询总行数
     * @param {Object} callBack(success,res|err)
     */
    loadCommodityInfoByPageTotal: function (keyword, commodityType, categoryName,supportNormsName,includeInv, commodityCat, callBack) {

        //console.log('key:'+keyword);
        var sql = "SELECT count(A.id) as ttlNum FROM commodityInfo A " +
            " LEFT JOIN commodityType B ON A.typeId=B.id AND A.sellerId=B.sellerId " +
            " LEFT JOIN supplierInfo C ON A.supplierId=C.id  " +
            " WHERE 1=1 AND ifnull(B.status,'') <>'9' AND ifnull(A.status,'')<>'9' ";
        var keyArr = [];
        sql += ' and A.sellerId=? ';
        keyArr.push(loginInfo.storeId);
        if(!Ext.isEmpty(keyword)){
            sql = sql + " AND  (A.name LIKE ?  ESCAPE '^' OR A.pinyinCode LIKE ?  ESCAPE '^' OR A.barcode LIKE ?  ESCAPE '^' )  ";
            keyArr.push("%"+replaceSQLiteCharacters(keyword)+"%");
            keyArr.push("%"+replaceSQLiteCharacters(keyword)+"%");
            keyArr.push("%"+replaceSQLiteCharacters(keyword)+"%");
        }
        if (!Ext.isEmpty(commodityType)) {
            sql = sql + ' and A.typeId=? ';
            keyArr.push(commodityType);
        }
        if (!Ext.isEmpty(categoryName)) {
            sql = sql + ' and A.category=? ';
            keyArr.push(categoryName);
        }
        if (!Ext.isEmpty(supportNormsName)) {
            sql = sql + ' and A.isSupportNorms=? ';
            keyArr.push(supportNormsName);
        }

        if (!Ext.isEmpty(includeInv)) {
            sql = sql + ' and ifnull(B.isInventory,0)=? ';
            keyArr.push(includeInv);
        }
        if (!Ext.isEmpty(commodityCat)) {
            sql = sql + " and ifnull(A.category,'')=? ";
            keyArr.push(commodityCat);
        }

        getBySql(sql, keyArr, callBack);
    },

    /**
     * 分页查询参数数组
     * @param {Object} callBack(success,res|err)
     */
    loadCommodityInfoByPageParam: function (paramsArray, pageSize, pageIndex, callBack) {

        var sql = " SELECT A.*,B.name AS typeName,C.name AS supplierName,CASE A.status when '0' then '下架' when '1' then '上架' when '2' then '卖完了' when '9' then '删除' else '' END AS statusName  " +
            " ,CASE A.labelPrint WHEN '0' THEN '否' WHEN '1' THEN  '是' ELSE '' END AS labelPrintName " +
            " ,CASE A.soldoutStatus WHEN '0' THEN '正常' WHEN '1' THEN '沽清' ELSE '' END AS soldoutStatusName " +
            " ,CASE ifnull(A.selected,'0') WHEN '0' THEN '否' WHEN '1' THEN  '是' ELSE '' END AS selectedName " +
            " ,CASE ifnull(A.category,'1') WHEN '1' THEN '否' WHEN '2' THEN  '是' ELSE '' END AS categoryName " +
            " ,CASE ifnull(A.isSupportNorms,'0') WHEN '0' THEN '否' WHEN '1' THEN  '是' ELSE '否' END AS supportNormsName " +
            " FROM commodityInfo A LEFT JOIN commodityType B ON A.typeId=B.id AND A.sellerId=B.sellerId " +
            " LEFT JOIN supplierInfo C ON A.supplierId=C.id  WHERE 1=1 AND ifnull(A.status,'0') not in ('0','9')  and ifnull(A.isWeight,'0')<>'1' and A.sellerId=? ";

        var keyArr = [];
        keyArr.push(loginInfo.storeId);
        if (paramsArray != null) {
            Ext.Array.forEach(paramsArray, function (arr) {
                if (arr.length == 3) {
                    sql=sql+" "+ arr[0];
                        Ext.Array.forEach(arr[1], function (paramKey) {
                            if(arr[2]=="1") {
                                keyArr.push('%'+replaceSQLiteCharacters(paramKey)+'%')
                            }else{
                                keyArr.push(paramKey);
                            }
                        });
                }
            });
        }

        sql = sql + " order by A.name,A.typeId  asc limit " + pageSize + " offset (" + pageIndex + "-1)*" + pageSize;
        loadBySqlParam(sql, keyArr, callBack);
    },

    /**
     * 分页查询参数数组总行数
     * @param {Object} callBack(success,res|err)
     */
    loadCommodityInfoByPageTotalParam: function (paramsArray, callBack) {

        var sql = "SELECT count(A.id) as ttlNum FROM commodityInfo A " +
            " LEFT JOIN commodityType B ON A.typeId=B.id AND A.sellerId=B.sellerId " +
            " LEFT JOIN supplierInfo C ON A.supplierId=C.id  " +
            " WHERE 1=1 AND ifnull(A.status,'')<>'9' AND ifnull(A.isWeight,'0')<>'1' ";
        var keyArr = [];
        sql += ' and A.sellerId=? ';
        keyArr.push(loginInfo.storeId);
        if (paramsArray != null) {
            Ext.Array.forEach(paramsArray, function (arr) {
                if (arr.length == 3) {
                    sql=sql+" "+ arr[0];
                    Ext.Array.forEach(arr[1], function (paramKey) {
                        if(arr[2]=="1") {
                            keyArr.push('%'+replaceSQLiteCharacters(paramKey)+'%')
                        }else{
                            keyArr.push(paramKey);
                        }
                    });
                }
            });
        }


        getBySql(sql, keyArr, callBack);
    },

    /**
     * 只查询商品名称
     * @param {Object} callBack(success,res|err)
     */
    loadCommodityNameInfo: function (callBack) {
        var sql = " SELECT A.name FROM commodityInfo A  WHERE ifnull(A.status,'')<>'9' AND A.sellerId=?  ";
        loadBySqlParam(sql, [loginInfo.storeId], callBack);
    },

    /**
     * 检查商品名称是否存在
     * @param {Object} callBack(success,res|err)
     */
    checkCommodityNameExist: function (name, id, callBack) {
        var keyArr = [];
        var sql = "SELECT * FROM commodityInfo WHERE 1=1 AND ifnull(status,'')<>'9' AND sellerId= ? ";
        keyArr.push(loginInfo.storeId);
        if (id) {
            sql = sql + ' and id <> ? ';
            keyArr.push(id);
        }
        if (!Ext.isEmpty(name)) {
            sql = sql + ' and name = ? ';
            keyArr.push(name);
        }
        loadBySqlParam(sql, keyArr, callBack);
    },

    /**
     * 检查商品条码是否存在
     * @param {Object} callBack(success,res|err)
     */
    checkCommoditybarcodeExist: function (barcode, id, callBack) {
        var keyArr = [];
        var sql = "SELECT * FROM commodityInfo WHERE 1=1 AND ifnull(status,'')<>'9' AND sellerId= ? ";
        keyArr.push(loginInfo.storeId);
        if (id) {
            sql = sql + ' and id <> ? ';
            keyArr.push(id);
        }
        if (!Ext.isEmpty(barcode)) {
            sql = sql + ' and barcode = ? ';
            keyArr.push(barcode);
        }
        loadBySqlParam(sql, keyArr, callBack);
    },

    /**
     * 检查商品名称是否允许删除
     * @param {Object} callBack(success,res|err)
     */
    checkCommodityNotAllowDelete: function (multiIds, callBack) {

        var keyArr = [];
        var sql = "SELECT commodityId  FROM purchaseDetail WHERE ifnull(purchaseNum,0)<>ifnull(arrivalNum,0) AND ifnull(status,'')<>'9'  AND commodityId IN ("+multiIds+") GROUP BY commodityId UNION " +
            " SELECT aCommodityId FROM  assembleRule  WHERE ifnull(status,'')<>'9' AND aCommodityId IN ("+multiIds+") UNION " +
            " SELECT bCommodityId FROM  assembleRule  WHERE ifnull(status,'')<>'9' AND bCommodityId IN ("+multiIds+") UNION " +
            " SELECT cCommodityId FROM  assembleRule  WHERE ifnull(status,'')<>'9' AND cCommodityId IN ("+multiIds+") UNION " +
            " SELECT dCommodityId FROM  assembleRule  WHERE ifnull(status,'')<>'9' AND dCommodityId IN ("+multiIds+") ";


        loadBySqlParam(sql, keyArr, callBack);
    },
    /**
     *判断商品是否存在于套餐内
     */
    isExistCombineCommodity: function(queryId, callback) {
        var sql = "SELECT * FROM commodityinfo WHERE ifnull(category,'')='2' AND id<>? AND comboMealsJson LIKE ?";
        loadBySqlParam(sql, [queryId, '%' + queryId + '%'], function(success, datas) {
            if (success) {
                callback && callback(true, datas);
            } else {
                callback && callback(false, '查询出错');
            }
        });
    },

}