

var PurchaseDao={
    /**
     * 根据id查询
     * @param {Object} callback(success,err)
     */
    getById : function(id, callback) {
        var sql = "SELECT * FROM purchaseInfo where id=? and sellerId=?";
        getBySql(sql,[id,loginInfo.storeId],callback);
    },




    /**
     * 查询
     * @param {Object} callBack(success,res|err)
     */
    loadSearchInfo : function(supplierName,purchaseNo,startDate,endDate,callBack) {
        //console.log(keyword);
        var sql = "SELECT id,supplierId,arrivalDate,totalAmount,commodifyNum,supplierName,purchaseDate," +
            "CASE status WHEN '1' THEN '待确认' WHEN '2' THEN '部分到货' end as status," +
            "CASE purchaseType WHEN '0' THEN '进货单' end as purchaseType " +
            " from purchaseInfo  WHERE status!='3' and purchaseType='0'" ;
        var keyArr=[];
        if(supplierName){
            sql=sql+' AND  supplierName = ?   ';
            keyArr.push(supplierName);
        }

        if(!Ext.isEmpty(purchaseNo)){
            sql=sql+" AND  id like ? ESCAPE '^'  ";
            keyArr.push('%'+replaceSQLiteCharacters(purchaseNo)+'%');
        }

        if (startDate && endDate)
        {
            sql=sql+' AND  date(purchaseDate) BETWEEN ? AND ? ';
            keyArr.push(startDate);
            keyArr.push(endDate);
        }else if(startDate){
            sql=sql+' AND  date(purchaseDate) >= ?  ';
            keyArr.push(startDate);
        }else if(endDate){
            sql=sql+' AND  date(purchaseDate) <= ?  ';
            keyArr.push(endDate);
        }
        sql=sql+'Order by purchaseDate';

        loadBySqlParam(sql,keyArr, callBack);
    },

    /**
     * 根据Id查询到货数量小于进货数量的数据
     * @param {Object} callBack(success,res|err)
     */
    loadArrivalById : function(id,callBack) {
        var sql = "SELECT * from purchaseInfo a  WHERE a.id=? and  a.commodifyNum > (SELECT SUM(c.arrivalNum) AS arrivalNum FROM purchaseDetail c WHERE c.purchaseId=? ) " ;
        loadBySqlParam(sql,[id,id], callBack);
    },

    /**
     *增加类型
     */
    add : function(sqlData, callBack) {
        insert("purchaseInfo", sqlData, callBack);
    },

    /**
     *删除类型
     */
    delete : function(id, callBack) {
        del("purchaseInfo", id, callBack);
    },

    ///**
    // *删除进货申请及其关联的进货申请明细
    // */
    //deletePurchaseAndPurchaseDetail : function(id, callBack) {
    //    del("purchaseInfo", id, callBack);
    //},
    /**
     * 更新类型
     * @param {Object} callback(success,err)
     */
    update : function(sqlData,id, callback) {
        update('purchaseInfo',sqlData,id,callback)
    },



    /**
     * 查询所有数据
     * @param {Object} callBack(success,res|err)
     */
    loadAllData : function(callBack) {
        //console.log(keyword);
        var sql = "SELECT * FROM purchaseInfo ";
        loadBySql(sql, callBack);
    },


    /**
     * 分页查询进货单
     * @param {Object} callback(success,res|err)
     */
    loadPurchaseByPage : function(supplierName,purchaseNo,startDate,endDate,limitCount,pageIndex, callback) {

        var sql = "SELECT id,supplierId,arrivalDate,round(totalAmount,2) totalAmount,round(commodifyNum,2) commodifyNum," +
            " supplierName,purchaseDate," +
            "CASE status WHEN '1' THEN '待确认' WHEN '2' THEN '部分到货' end as status," +
            "CASE purchaseType WHEN '0' THEN '进货单' end as purchaseType " +
            " from purchaseInfo  WHERE sellerId=? and ifnull(status,'') in ('1','2') and purchaseType='0'" ;
        var keyArr=[];
        keyArr.push(loginInfo.storeId);
        if(supplierName){
            sql=sql+' AND  supplierId = ?  ';
            keyArr.push(supplierName);
        }

        if(!Ext.isEmpty(purchaseNo)){
            sql=sql+" AND  id like ?  ESCAPE '^'  ";
            keyArr.push('%'+replaceSQLiteCharacters(purchaseNo)+'%');
        }

        if (startDate && endDate)
        {
            sql=sql+' AND  date(purchaseDate) BETWEEN ? AND ? ';
            keyArr.push(startDate);
            keyArr.push(endDate);
        }else if(startDate){
            sql=sql+' AND  date(purchaseDate) >= ?  ';
            keyArr.push(startDate);
        }else if(endDate){
            sql=sql+' AND  date(purchaseDate) <= ?  ';
            keyArr.push(endDate);
        }
        sql=sql+" Order by purchaseDate desc limit "+limitCount+" offset ("+pageIndex+"-1)*"+limitCount;

        loadBySqlParam(sql,keyArr, callback);
    },

    /**
     * 分页查询进货单总行数
     * @param {Object} callback(success,res|err)
     */
    loadPurchaseByPageTotal : function(supplierName,purchaseNo,startDate,endDate, callback) {

        var sql = "SELECT count(id) as ttlNum from purchaseInfo  WHERE sellerId=? and ifnull(status,'') in ('1','2') and purchaseType='0' " ;

        var keyArr=[];
        keyArr.push(loginInfo.storeId);
        if(supplierName){
            sql=sql+' AND  supplierId = ?  ';
            keyArr.push(supplierName);
        }

        if(!Ext.isEmpty(purchaseNo)){
            sql=sql+" AND  id like ?  ESCAPE '^' ";
            keyArr.push('%'+replaceSQLiteCharacters(purchaseNo)+'%');
        }
        if (startDate && endDate)
        {
            sql=sql+' AND  date(purchaseDate) BETWEEN ? AND ? ';
            keyArr.push(startDate);
            keyArr.push(endDate);
        }else if(startDate){
            sql=sql+' AND  date(purchaseDate) >= ?  ';
            keyArr.push(startDate);
        }else if(endDate){
            sql=sql+' AND  date(purchaseDate) <= ?  ';
            keyArr.push(endDate);
        }

        getBySql(sql,keyArr, callback);
    },

    /**
     * 分页查询进货单总行数
     * @param {Object} callback(success,res|err)
     */
    loadRefundPurchaseByPageTotal : function(supplierName,purchaseNo,startDate,endDate, callback) {

        var sql = "SELECT count(id) as ttlNum from purchaseInfo  WHERE sellerId=? and ifnull(status,'') in ('1','2') and purchaseType='1' " ;

        var keyArr=[];
        keyArr.push(loginInfo.storeId);
        if(supplierName){
            sql=sql+' AND  supplierId = ?  ';
            keyArr.push(supplierName);
        }

        if(!Ext.isEmpty(purchaseNo)){
            sql=sql+" AND  id like ?  ESCAPE '^' ";
            keyArr.push('%'+replaceSQLiteCharacters(purchaseNo)+'%');
        }
        if (startDate && endDate)
        {
            sql=sql+' AND  date(purchaseDate) BETWEEN ? AND ? ';
            keyArr.push(startDate);
            keyArr.push(endDate);
        }else if(startDate){
            sql=sql+' AND  date(purchaseDate) >= ?  ';
            keyArr.push(startDate);
        }else if(endDate){
            sql=sql+' AND  date(purchaseDate) <= ?  ';
            keyArr.push(endDate);
        }

        getBySql(sql,keyArr, callback);
    },

    /**
     * 分页查询进货单
     * @param {Object} callback(success,res|err)
     */
    loadRefundPurchaseByPage : function(supplierName,purchaseNo,startDate,endDate,limitCount,pageIndex, callback) {

        var sql = "SELECT id,supplierId,arrivalDate,round(totalAmount,2) totalAmount,round(commodifyNum,2) commodifyNum," +
            " supplierName,purchaseDate," +
            "CASE status WHEN '1' THEN '待确认' WHEN '2' THEN '部分到货' end as status," +
            "CASE purchaseType WHEN '1' THEN '退货单' end as purchaseType " +
            " from purchaseInfo  WHERE sellerId=? and ifnull(status,'') in ('1','2') and purchaseType='1'" ;
        var keyArr=[];
        keyArr.push(loginInfo.storeId);
        if(supplierName){
            sql=sql+' AND  supplierId = ?  ';
            keyArr.push(supplierName);
        }

        if(!Ext.isEmpty(purchaseNo)){
            sql=sql+" AND  id like ?  ESCAPE '^'  ";
            keyArr.push('%'+replaceSQLiteCharacters(purchaseNo)+'%');
        }

        if (startDate && endDate)
        {
            sql=sql+' AND  date(purchaseDate) BETWEEN ? AND ? ';
            keyArr.push(startDate);
            keyArr.push(endDate);
        }else if(startDate){
            sql=sql+' AND  date(purchaseDate) >= ?  ';
            keyArr.push(startDate);
        }else if(endDate){
            sql=sql+' AND  date(purchaseDate) <= ?  ';
            keyArr.push(endDate);
        }
        sql=sql+" Order by purchaseDate desc limit "+limitCount+" offset ("+pageIndex+"-1)*"+limitCount;
        loadBySqlParam(sql,keyArr, callback);
    },
}