var ServicePlaceDao = {

    /**
     * 查询
     * @param {Object} callBack(success,res|err)
     */
    loadSearchSPInfo: function (typeName, placeName, callBack) {
        //console.log(keyword);
        var sql = "SELECT a.id,a.placeName,a.remark,b.typeName,a.personNum,CASE a.status WHEN '0' THEN '空闲' WHEN '1' THEN '使用' WHEN '2' THEN '禁用' WHEN '3' THEN '留位' END AS status,a.sequence " +
            " from servicePlace a JOIN servicePlaceType b ON a.typeId=b.id" +
            " where a.sellerId = ? and ifnull(a.status,'0')<>'9'  ";
        var keyArr = [loginInfo.storeId];
        if (!Ext.isEmpty(typeName)) {
            sql = sql + " and  typeName like ?   ESCAPE '^'  ";
            keyArr.push('%' + replaceSQLiteCharacters(typeName) + '%');
        }
        if (!Ext.isEmpty(placeName)) {
            sql = sql + " and  placeName like ?  ESCAPE '^' ";
            keyArr.push('%' + replaceSQLiteCharacters(placeName) + '%');
        }
        sql = sql + 'Order by a.placeName';

        loadBySqlParam(sql, keyArr, callBack);
    },

    /**
     * 查询
     * @param {Object} callback(success,res|err)
     */
    checkType: function (typeId, callback) {
        var sql = "SELECT * FROM servicePlace  where sellerId = ? and ifnull(status,'0')<>'9'  ";
        var keyArr = [loginInfo.storeId];

        if (!Ext.isEmpty(typeId)) {
            keyArr.push(typeId);
            sql += '  and typeId = ? ';
        }

        loadBySqlParam(sql, keyArr, callback);
    },

    /**
     * 修改时，判断桌位名称是否存在
     * @param {Object} callback(success,res|err)
     */
    getByIdAndPlaceName: function (id, placeName, callback) {
        if (Ext.isEmpty(id) || Ext.isEmpty(placeName)) {
            return;
        }
        var sql = "SELECT * FROM servicePlace  where ifnull(status,'')<>'9' and id<>? and placeName=? and sellerId = ? ";
        loadBySqlParam(sql, [id, placeName, loginInfo.storeId], callback);
    },

    /**
     * 新增时，判断桌位名称是否存在
     * @param {Object} callback(success,res|err)
     */
    getByPlaceName: function (placeName,typeId, callback) {
        if (Ext.isEmpty(placeName) && Ext.isEmpty(typeId)) {
            return;
        }
        var sql = "SELECT * FROM servicePlace  where ifnull(status,'')<>'9' and placeName=? and typeId = ? and sellerId = ? ";
        console.log(sql,[placeName, loginInfo.storeId]);
        loadBySqlParam(sql, [placeName,typeId, loginInfo.storeId], callback);
    },

    /**
     * 新增时，判断桌位名称是否存在
     * @param {Object} callback(success,res|err)
     */
    getByPlaceNames: function (placeNameArr, callback) {
        if (Ext.isEmpty(placeNameArr)) {
            return;
        }
        if (!isArray(placeNameArr)) {
            return;
        }
        if (placeNameArr.length == 0) {
            return;
        }
        var sql = "SELECT * FROM servicePlace  where ifnull(status,'0')<>'9' and sellerId ='" + loginInfo.storeId + "' and placeName in ";
        for (var j = 0; j < placeNameArr.length; j++) {
            if (j == 0 && j == placeNameArr.length - 1) {
                sql += "(?)";
            }
            else if (j == 0) {
                sql += "(?,";
            } else if (j == placeNameArr.length - 1) {
                sql += "?)";
            } else {
                sql += "?,";
            }
        }

        loadBySqlParam(sql, placeNameArr, callback);
    },


    /**
     *增加桌位区域
     */
    add: function (sqlData, callBack) {
        insert("servicePlace", sqlData, callBack);
    },

    /**
     *批量增加桌位区域
     */
    batchAdd: function (sqlDataArr, callBack) {
        //batchInsert("servicePlace", sqlDataArr, callBack);
    },


    /**
     *删除桌位区域
     */
    delete: function (id, callBack) {
        del("servicePlace", id, callBack);
    },

    /**
     * 根据id查询桌位区域数据
     * @param {Object} callback(success,err)
     */
    getSPById: function (id, callback) {
        var sql = "SELECT * FROM servicePlace where id=? and sellerId = ? ";
        getBySql(sql, [id, loginInfo.storeId], callback);
    },

    /**
     * 更新桌位区域数据
     * @param {Object} callback(success,err)
     */
    updateById: function (sqlData, id, callback) {
        update('servicePlace', sqlData, id, callback)
    },


    /**
     * 分页查询
     * @param {Object} callback(success,res|err)
     */
    loadServicePlaceByPage: function (typeId, placeName, limitCount, pageIndex, callback) {

        var sql = "SELECT a.id,a.placeName,a.remark,b.typeName,a.personNum,CASE a.status WHEN '0' THEN '空闲' WHEN '1' THEN '使用' WHEN '2' THEN '禁用' WHEN '3' THEN '留位' END AS status,a.sequence " +
            " from servicePlace a JOIN servicePlaceType b ON a.typeId=b.id " +
            " where ifnull(a.status,'')<>'9' and a.sellerId = ? ";
        var keyArr = [loginInfo.storeId];
        if (!Ext.isEmpty(typeId)) {
            sql = sql + " and  typeId like ? ESCAPE '^' ";
            keyArr.push('%' + replaceSQLiteCharacters(typeId) + '%');
        }
        if (!Ext.isEmpty(placeName)) {
            sql = sql + " and  placeName like ? ESCAPE '^' ";
            keyArr.push('%' + replaceSQLiteCharacters(placeName) + '%');
        }

        sql = sql + " Order by a.sequence limit ? offset ? ";
        keyArr.push(limitCount);
        keyArr.push((pageIndex - 1) * limitCount);

        loadBySqlParam(sql, keyArr, callback);
    },

    /**
     * 分页查询
     * @param {Object} callback(success,res|err)
     */
    loadServicePlaceByPageTotal: function (typeId, placeName, callback) {

        var sql = "SELECT count(a.id) as ttlNum from servicePlace a JOIN servicePlaceType b ON a.typeId=b.id where ifnull(a.status,'0')!='9' and a.sellerId = ? ";
        var keyArr = [loginInfo.storeId];
        if (!Ext.isEmpty(typeId)) {
            sql = sql + " and  typeId like ? ESCAPE '^' ";
            keyArr.push('%' + replaceSQLiteCharacters(typeId) + '%');
        }
        if (!Ext.isEmpty(placeName)) {
            sql = sql + " and  placeName like ? ESCAPE '^' ";
            keyArr.push('%' + replaceSQLiteCharacters(placeName) + '%');
        }

        getBySql(sql, keyArr, callback);
    },

}
