var SupplierDao = {
    /**
     * 根据id查询供应商数据
     * @param {Object} callback(success,err)
     */
    getById: function (id, callback) {
        var sql = "SELECT * FROM supplierInfo where id=? AND sellerId = ? and ifnull(status,'0')<>'9' ";
        getBySql(sql, [id, loginInfo.storeId], callback);
    },

    /**
     * 根据供应商名称查询供应商数据
     * @param {Object} callback(success,err)
     */
    getByName: function (name, callback) {
        var sql = "SELECT * FROM supplierInfo where name=? AND sellerId = ? and ifnull(status,'0')<>'9' ";
        loadBySqlParam(sql, [name, loginInfo.storeId], callback);
    },

    /**
     * 根据id和供应商名称查询供应商数据
     * @param {Object} callback(success,err)
     */
    getByIdAndName: function (id, name, callback) {

        var sql = "SELECT * FROM supplierInfo where id <> ? and name= ? AND sellerId = ? and ifnull(status,'0')<>'9' ";
        loadBySqlParam(sql, [id, name, loginInfo.storeId], callback);
    },

    /**
     * 查询
     * @param {Object} callBack(success,res|err)
     */
    loadSearchInfo: function (param, callBack) {
        //console.log(keyword);
        var sql = "SELECT * from supplierInfo where 1=1 AND sellerId = ? and  ifnull(status,'0')<>'9' ";
        var keyArr = [loginInfo.storeId];
        if (!Ext.isEmpty(param)) {
            sql = sql + " and  name like ? ESCAPE '^'  ";
            keyArr.push('%' + replaceSQLiteCharacters(param) + '%');
        }
        sql = sql + 'Order by name';

        loadBySqlParam(sql, keyArr, callBack);
    },

    /**
     *增加类型
     */
    add: function (sqlData, callBack) {
        insert("supplierInfo", sqlData, callBack);
    },

    /**
     *删除类型
     */
    delete: function (id, callBack) {
        del("supplierInfo", id, callBack);
    },
    /**
     * 更新类型
     * @param {Object} callback(success,err)
     */
    update: function (sqlData, id, callback) {
        update('supplierInfo', sqlData, id, callback)
    },


    /**
     * 查询所有数据
     * @param {Object} callBack(success,res|err)
     */
    loadAllData: function (callBack) {
        //console.log(keyword);
        var sql = "SELECT * FROM supplierInfo WHERE ifnull(status,'0')<>'9' and IFNULL(status,'')<>'1' and sellerId = ?  ";
        loadBySqlParam(sql, [loginInfo.storeId], callBack);
    },


    /**
     * 分页查询
     * @param {Object} callback(success,res|err)
     */
    loadSupplierByPage: function (supplierName, limitCount, pageIndex, callback) {

        var sql = "SELECT * from supplierInfo where ifnull(status,'0')<>'9' AND IFNULL(status,'')<>'1' and sellerId = ? ";
        var keyArr = [loginInfo.storeId];
        if (!Ext.isEmpty(supplierName)) {
            sql = sql + " and  name like ?  ESCAPE '^' ";
            keyArr.push('%' + replaceSQLiteCharacters(supplierName) + '%');
        }
        sql = sql + " Order by name limit ? offset ? ";
        keyArr.push(limitCount);
        keyArr.push((pageIndex - 1) * limitCount);
        loadBySqlParam(sql, keyArr, callback);
    },

    /**
     * 分页查询总行数
     * @param {Object} callback(success,res|err)
     */
    loadSupplierByPageTotal: function (supplierName, callback) {

        var sql = "SELECT count(id) as ttlNum from supplierInfo where ifnull(status,'')<>'9' AND IFNULL(status,'')<>'1' and sellerId = ?";
        var keyArr = [loginInfo.storeId];
        // getBySql()
        //if (supplierName)
        if (!Ext.isEmpty(supplierName)) {
            sql = sql + " and  name like ? ESCAPE '^' ";
            keyArr.push('%' + replaceSQLiteCharacters(supplierName) + '%');
        }
        getBySql(sql, keyArr, callback);
    },

    //检查是否在使用供应商
    checkSupplierInUse: function (id, callback) {
        var sql = "SELECT COUNT(*) as ttlNum FROM commodityinfo WHERE sellerId=? AND supplierId=? and ifnull(status,'')<>'9' ";
        var keyArr = [];
        keyArr.push(loginInfo.storeId);
        keyArr.push(id);
        getBySql(sql, keyArr, callback);
    },
}